function y = CIR_LL(params, r, dt);

alpha = params(1);
mu    = params(2);
sigma = params(3);

% Compute the scalar quantities
N = length(r);
c = 2*alpha/sigma^2/(1-exp(-alpha*dt));
q = 2*alpha*mu/sigma^2 - 1;

% Compute the vectors needed for the log-likelihood
u = c.*r(1:N-1).*exp(-alpha*dt);
v = c.*r(2:N);
z = 2.*sqrt(u.*v);
L = - u - v + 0.5.*q.*log(v./u) + log(besseli(q,z,1)) + z;

% The log-likelihood
LogLikelihood = (N-1)*log(c) + sum(L);

y = -LogLikelihood;

% Impose constraints on the parameters
if alpha<0 | mu<0 | sigma<0
	y = 1e100;
end


